module Math
  module_function \
    :acos,
    :acosh,
    :asin,
    :asinh,
    :atan,
    :atan2,
    :atanh,
    :cbrt,
    :cos,
    :cosh,
    :erf,
    :erfc,
    :exp,
    :frexp,
    :gamma,
    :hypot,
    :ldexp,
    :lgamma,
    :log,
    :log10,
    :log2,
    :modf,
    :sin,
    :sinh,
    :sqrt,
    :tan,
    :tanh

  private \
    :acos,
    :acosh,
    :asin,
    :asinh,
    :atan,
    :atan2,
    :atanh,
    :cos,
    :cosh,
    :erf,
    :erfc,
    :exp,
    :frexp,
    :hypot,
    :ldexp,
    :log,
    :log10,
    :log2,
    :modf,
    :sin,
    :sinh,
    :sqrt,
    :tan,
    :tanh
end
